@@ -80,16 +80,16 @@ case "$1" in
         #set -e
 
         # Auto-Create password
-        if [ ! -f /etc/benno/rest.secret ];then
-            openssl rand -hex 20 > /etc/benno/rest.secret
+        if [ ! -f /etc/benno-web/rest.conf ];then
             echo -n 'SHARED_SECRET = '  > /etc/benno-web/rest.conf
-            cat /etc/benno/rest.secret >> /etc/benno-web/rest.conf
+            if [ -f /etc/benno/rest.secret ];then
+                cat /etc/benno/rest.secret >> /etc/benno-web/rest.conf
+            else
+                cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 20 | head -n 1 >> /etc/benno-web/rest.conf
+            fi
         fi
 
         # Auth.d
-        if [ ! -d /etc/benno-web/auth.d ];then
-            mkdir /etc/benno-web/auth.d
-        fi
         if [ ! -f /etc/benno-web/auth.conf ];then
             echo "# benno_auth.d configuration file" >> /etc/benno-web/auth.conf
             echo "#"                                 >> /etc/benno-web/auth.conf
@@ -97,6 +97,12 @@ case "$1" in
             echo ""                                  >> /etc/benno-web/auth.conf
         fi
 
+        # clear cache
+        set +e
+        if [ -d /var/cache/benno-web/templates_c/default/ ];then
+            /bin/rm /var/cache/benno-web/templates_c/default/*.php 2>/dev/null
+        fi
+        set -e
     ;;
 
     abort-upgrade|abort-remove|abort-deconfigure)
