@@ -47,7 +47,17 @@ if (! $passwd) {
     $App->redirect('default',array('MSG'=>'ERR_NOPASS'));
 }
 
+$RESTconf = new ApplicationConfig($App->configdir);
+$RESTconf->load($App->getConfig('REST_CONFIG','rest.conf'),false);
+
+// defaults: compatibility to deprecated configuration
+$base_url_mainconf = $App->getConfig('BASE_URL','http://localhost:21080');
+$rest_data['URL']  = $RESTconf->getConfig('BASE_URL',$base_url_mainconf);
+$rest_data['USER'] = $RESTconf->getConfig('REST_USER','benno2');
+$rest_data['PASS'] = $RESTconf->getConfig('SHARED_SECRET',$App->getConfig('SHARED_SECRET'));
+
 $User = new User($userid);
+$User->setRestData($rest_data);  // set defaults from config
 try {
     if ($authscript && is_readable($authscript)) {
         $User->loadExternal($authscript,$passwd);
@@ -81,16 +91,9 @@ foreach ($FilterList as $Filter) {
     $filterString .= $Filter->getString();
 }
 
-$RESTconf = new ApplicationConfig($App->configdir);
-$RESTconf->load($App->getConfig('REST_CONFIG','rest.conf'),false);
-
-// defaults: compatibility to deprecated configuration
-$base_url_mainconf = $App->getConfig('BASE_URL','http://localhost:21080');
-$base_url  = $RESTconf->getConfig('BASE_URL',$base_url_mainconf);
-$rest_user = $RESTconf->getConfig('REST_USER','benno2');
-$rest_pass = $RESTconf->getConfig('SHARED_SECRET',$App->getConfig('SHARED_SECRET'));
-
-$Backend = new Backend($base_url,$rest_user,$rest_pass,$filterString);
+$rest_data = $User->getRestData();
+$Backend = new Backend($rest_data['URL'],$rest_data['USER'],$rest_data['PASS'],
+                       $filterString);
 
 // initialize session
 $App->setSession('ACCESS_LEVEL',$User->getAuthzLevel());
@@ -129,6 +132,9 @@ catch (Exception $e) {
     $App->log('Error loading application state: '.$e->getMessage());
 }
 
+// set language on change and after login for 32 days
+setcookie("BENNO_LANGUAGE", $LANG, time()+2764800, dirname($_SERVER['REQUEST_URI']));
+
 // redirect after login
 if (!$redirect = $App->getSession('LOGIN_REDIRECT')) {
     $redirect = 'greeting';
