@@ -34,6 +34,8 @@ require_once 'model/AppState.php';
 $AppState = new AppState($USER->id,'searchMaskState',$App->getSession('searchMaskState'));
 $AppState->save();
 
+$exitview = $App->getSession('exitview');
+
 try {
     $Backend->destroy_bennorest_session();
 }
@@ -51,5 +53,10 @@ $App->setSession('ACCESS_LEVEL',0);
 session_destroy();
 
 $App->log('User '.$USER->id.' logged out',1);
-$App->redirect('default',$messages);
+if ($exitview) {
+    $App->view = $exitview;
+}
+else {
+    $App->redirect('default',$messages);
+}
 ?>
