@@ -34,7 +34,7 @@
 
 $extForm = $App->getParam('ext');
 $queryId = sha1(serialize($extForm));
-$ExtQuery = new Query($queryId,
+$ExtQuery = new Query($queryId,$archive,
         $extForm['text'],
         DateConvert::Date2Timestamp($extForm['dateFrom'],$App->date_format),
         DateConvert::Date2Timestamp($extForm['dateTo'],$App->date_format),
@@ -54,7 +54,7 @@ $SimpleQuery = new Query('empty');
 
 try {
     // fresh search, thus we start with position 1
-    $QueryResult = $Backend->query($ExtQuery,0,$search_limit);
+    $QueryResult = $Backend->query($archive,$ExtQuery,0,$search_limit);
     if ($QueryResult->found == 0) {
         $App->setMsg('MSG_NOTFOUND');
         $sessionMailId = '';
