@@ -52,8 +52,8 @@ class Benno
      */
     function Benno ()
     {
-        $this->infoText = 'Benno MailArchiv Version 2.4.0'; 
-        $this->buildInfo= '70a77e320171110';
+        $this->infoText = 'Benno MailArchiv Version 2.4.1'; 
+        $this->buildInfo= '171207085915/05e5481';
         $this->buildYear= '2017';
     }
 
