@@ -71,6 +71,22 @@ class MailObject
     }
 
 
+    function setBody($content,$content_type)
+    {
+        if ($content_type = 'text/plain') {
+            $this->body = nl2br($content);
+        }
+        else {
+            $this->body = $content;
+        }
+    }
+
+    function setDate($date) { $this->date = $date; }
+
+
+    function setTime($time) { $this->time = $time; }
+
+
     function setError($msg_sym)
     {
         global $App;
