@@ -53,6 +53,8 @@ if (!$search_limit) {
 $EMail       = $App->getSession('EMail');
 $QueryResult = $App->getSession('QueryResult');
 $Backend     = $App->getSession('Backend');
+// current archive
+$archive     = $App->getSession('archive');
 
 // fetch query field entries from session
 $searchmin   = $App->getSession('searchmin');
